# This rpm spec file is based on packaging approach used by linux-system-roles
# project, as there are no Fedora packaging guidelines for ansible or better
# examples to follow. Target OS is RHEL or CentOS 7.

Name:           tendrl-ansible
Version:        1.6.3
Release: 12%{?dist}
Summary:        Ansible roles and playbooks for Tendrl

License:        LGPLv2.1
Url:            https://github.com/Tendrl/tendrl-ansible
Source0:        %{name}-%{version}.tar.gz
BuildArch:      noarch

Requires:       ansible >= 2.4
Requires:       python-dns
Requires:       python2-pyasn1 <= 0.1.9

# All ansible roles from tendrl-ansible will have this prefix added into the
# name of the role (name of the directory with the role) to prevent conflicts.
%global roleprefix %{name}.

Patch0001: 0001-Revert-downstream-specific-minimum-required-RAM-and-.patch
Patch0002: 0002-Increse-Max-no-of-open-Fds-to-a-higher-number.patch
Patch0003: 0003-Fix-the-memory-requirement-issue-in-prechecks.yml.patch
Patch0004: 0004-Revert-Max-Fd-Change.patch
Patch0005: 0005-daemon-reload-before-starting-carbon-cache.patch
Patch0006: 0006-Use-systemd-instead-service-for-units-uses-daemon_re.patch
Patch0007: 0007-Set-minimum-memory-requirement-criteria-to-3700-MiB.patch
Patch0008: 0008-keep-README-file-intact-as-in-upstream.patch
Patch0009: 0009-update-assert-tasks-to-work-with-ansible-2.7.patch
Patch0010: 0010-tendrl-server-no-longer-open-3000-tcp-for-grafana.patch
Patch0011: 0011-Added-new-taks-under-monitoring-integration-to-updat.patch
Patch0012: 0012-Modified-configuring-grafana-root_path-taks-to-use-i.patch
Patch0013: 0013-Added-new-comment-for-grafana-root_url-path-configur.patch
Patch0014: 0014-Modified-graphite-db-initialization-command-for-grap.patch
Patch0015: 0015-Solving-permission-denied-problem-for-graphite.patch
Patch0016: 0016-Restricting-graphite-web-port-form-outside-access.patch

%description
Ansible roles and playbooks for installation of Tendrl, based on upstream
Tendrl documentation.


%prep
%setup -q
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%patch0007 -p1
%patch0008 -p1
%patch0009 -p1
%patch0010 -p1
%patch0011 -p1
%patch0012 -p1
%patch0013 -p1
%patch0014 -p1
%patch0015 -p1
%patch0016 -p1

%build
# reference roles by prefixed name in site.yml playbook file
sed -i 's/- \(tendrl-server\)/- %{roleprefix}\1/g' site.yml
sed -i 's/- \(tendrl-storage-node\)/- %{roleprefix}\1/g' site.yml

# reference playbooks by full paths in site.yml playbook file
sed -i 's!prechecks.yml!%{_pkgdocdir}/&!g'                   site.yml

%install
mkdir -p $RPM_BUILD_ROOT%{_datadir}/ansible/roles

# install ansible roles
cp -pR roles/tendrl-ansible.tendrl-server          $RPM_BUILD_ROOT%{_datadir}/ansible/roles/%{roleprefix}tendrl-server
cp -pR roles/tendrl-ansible.tendrl-storage-node    $RPM_BUILD_ROOT%{_datadir}/ansible/roles/%{roleprefix}tendrl-storage-node

mkdir -p $RPM_BUILD_ROOT%{_pkgdocdir}/

# install playbooks
install -p -m 644 site.yml                     $RPM_BUILD_ROOT%{_pkgdocdir}/site.yml
install -p -m 644 prechecks.yml                $RPM_BUILD_ROOT%{_pkgdocdir}/prechecks.yml

# install readme, license and example files
install -p -m 644 README.md                    $RPM_BUILD_ROOT%{_pkgdocdir}/README.md
install -p -m 644 LICENSE                      $RPM_BUILD_ROOT%{_pkgdocdir}/LICENSE
install -p -m 644 hosts.example                $RPM_BUILD_ROOT%{_pkgdocdir}/hosts.example

%files
%{_datadir}/ansible/roles/%{roleprefix}tendrl-server
%{_datadir}/ansible/roles/%{roleprefix}tendrl-storage-node

# mark readme files in ansible roles as documentation
%doc %{_datadir}/ansible/roles/%{roleprefix}tendrl-server/README.md
%doc %{_datadir}/ansible/roles/%{roleprefix}tendrl-storage-node/README.md

# mark example site.yml file as documentation
%doc %{_pkgdocdir}/site.yml

# playbooks (referenced in site.yml) in doc dir (temporary HACK)
%doc %{_pkgdocdir}/prechecks.yml

# example of ansible inventory file for tendrl-ansible
%doc %{_pkgdocdir}/hosts.example

# readme and license files
%doc %{_pkgdocdir}/README.md
%license %{_pkgdocdir}/LICENSE

%changelog
* Mon May 06 2019 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-12
- Fixed bugs: 1645428
- Release tendrl-ansible 1.6.3-12

* Tue Dec 18 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-11
- Fixed bugs: 1655424,1655433
- Release tendrl-ansible 1.6.3-11

* Mon Nov 26 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-10
- Fixed bugs: 1650557
- Release tendrl-ansible 1.6.3-10

* Mon Nov 05 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-9
- Fixed bugs: 1642574
- Release tendrl-ansible 1.6.3-9

* Wed Oct 10 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-8
- Fixed bugs: 1637646
- Release tendrl-ansible 1.6.3-8

* Wed Oct 10 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-7.1
- fixes bugs 1638043
- Release tendrl-ansible 1.6.3-7.1

* Thu Aug 16 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-7
- Fixed bugs: 1570564
- Release tendrl-ansible 1.6.3-7

* Mon Jul 30 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-6
- Fixed bugs: 1608287
- Release tendrl-ansible 1.6.3-6

* Mon Jun 18 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-5
- Fixed bugs: 1560875
- Release tendrl-ansible 1.6.3-5

* Thu May 17 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-4
- Fixed bugs: 1560875
- Release tendrl-ansible 1.6.3-4

* Wed Apr 25 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-3
- Fixed bugs: 1570564
- Release tendrl-ansible 1.6.3-3

* Sat Apr 21 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-2
- Release tendrl-ansible 1.6.3-2

* Thu Apr 19 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.3-1
- Release tendrl-ansible 1.6.3-1

* Mon Apr 02 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.1-3
- Fixed bugs: 1559792
- Release tendrl-ansible 1.6.1-3

* Fri Mar 09 2018 Timothy Asir J <tjeyasin@redhat.com> - 1.6.1-1
- Release tendrl-ansible 1.6.1-1

* Tue Dec 12 2017  Shubhendu Ram Tripathi <shtripat@redht.com> - 1.5.4-7
  Release tendrl-ansible 1.5.4-7

* Fri Dec 08 2017  Shubhendu Ram Tripathi <shtripat@redht.com> - 1.5.4-6
  Release tendrl-ansible 1.5.4-6

* Thu Dec 07 2017  Shubhendu Ram Tripathi <shtripat@redht.com> - 1.5.4-5
  Release tendrl-ansible 1.5.4-5

* Tue Dec 05 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-4
  Fix firewall disable issue
  Release tendrl-ansible 1.5.4-4

* Tue Dec 05 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-3
  Release tendrl-ansible 1.5.4-3

* Thu Nov 23 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-2
  Release tendrl-ansible 1.5.4-2

* Fri Nov 03 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.4-1
  Release tendrl-ansible 1.5.4-1

* Thu Nov 02 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.3-3
  Bugfixes Bz#1502970
  Release tendrl-ansible 1.5.3-3

* Mon Oct 16 2017  Timothy Asir Jeyasingh <tjeyasin@redht.com> - 1.5.3-2
  Release tendrl-ansible 1.5.3-2

* Wed Sep 27 2017  Martin Bukatovič <mbukatov@redhat.com> - 1.5.3-1
- First release with tendrl-ansible provided in rpm package.
- Initial specfile based on rhel-system-roles packaging style.

